Documentation
¶
Overview ¶
Package df extracts useful info from that command on linux
Csv output is particularly supported, so that a csvfile-based enterprise's ETL tools can also monitor its servers and desktops
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Keys_String2PtrDfdata ¶
Keys_String2PtrDfdata is generic
func SortedKeys_String2PtrDfdata ¶
SortedKeys_String2PtrDfdata is generic
Types ¶
type Dfdata ¶
type Dfdata struct {
Name_ string // e.g. /dev/md1p1
DevName_ string // e.g. /dev/md1 (inferred)
Type_ string // e.g. local, network, etc
Mountpoint_ string // e.g. /
Sizegb_ string // e.g. 25G
Usedgb_ string // e.g. 10G
Availgb_ string // e.g. 15G
Usepct_ string // e.g. 43%
}
Dfdata holds df data
Click to show internal directories.
Click to hide internal directories.