Documentation
¶
Overview ¶
Package hp extracts useful info, using the hpaucli program, about all hp disk controllers on a linux system
Csv output is particularly supported, so that a csvfile-based enterprise's ETL tools can also monitor its servers and desktops
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Keys_String2PtrHpdata ¶
Keys_String2PtrHpdata is generic
func SortedKeys_String2PtrHpdata ¶
SortedKeys_String2PtrHpdata is generic
Types ¶
type Hpctrl ¶
type Hpctrl struct {
Type_ string
Slotnum_ string
Ctrlserial_ string
Ctrlstatus_ string
Cachestatus_ string
Batterystatus_ string
Ldlist []Hpld // list of all logical drives
Pdlist_ []Hppd // list of all physical drives
}
Hpctrl holds hp controller data
type Hpld ¶
type Hpld struct {
Pdas_ string // list of physical drives
Ldnum_ string // logical drive number
Ldstatus_ string
Ldsize_ string
Raid_ string
Lddev_ string // Os device name
Mountpts_ string
Ctrl_ *Hpctrl
}
Hpld holds Hp logical disk data
Click to show internal directories.
Click to hide internal directories.