Documentation
¶
Overview ¶
Package md extracts useful info from the mdadm command on linux
Csv output is particularly supported, so that a csvfile-based enterprise's ETL tools can also monitor its servers and desktops
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Keys_String2PtrMddata ¶
Keys_String2PtrMddata is generic
func SortedKeys_String2PtrMddata ¶
SortedKeys_String2PtrMddata is generic
Types ¶
type Mddata ¶
type Mddata struct {
Name_ string // e.g. md0
Status_ string // e.g. active
Raidtype_ string // e.g. raid1
Level_ string // e.g. 5
Members_ string // e.g. sda2[0]/sdb2[1]
Blocks_ string // e.g. 511988
Chunk_ string // e.g. 65536Kb
Bitmap_ string // e.g. 1/1
Nearcopies_ string // e.g. 2
Pages_ string // e.g. [4KB]
Superversion_ string // e.g. 1.2
Algo_ string // e.g. 2
Numcomponents_ string // e.g. [5/5] First num is ideal, second is actual
Componentstatus_ string // e.g. [U_]
Checkpct_ string // 40.2
Checkminutesleft_ string // 6137.7
Resync_ string // DELAYED
}
Mddata holds mdadm data
Click to show internal directories.
Click to hide internal directories.