Documentation
¶
Overview ¶
Package parted extracts useful info from that command on linux
Csv output is particularly supported, so that a csvfile-based enterprise's ETL tools can also monitor its servers and desktops
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Keys_String2PtrParteddata ¶
func Keys_String2PtrParteddata(_mp *map[string][]*Parteddata) []string
Keys_String2PtrParteddata is generic
func Parted ¶
func Parted(_verbose bool) (smap map[string][]*Parteddata)
Parted extracts parted data
func SortedKeys_String2PtrParteddata ¶
func SortedKeys_String2PtrParteddata(_mp *map[string][]*Parteddata) []string
SortedKeys_String2PtrParteddata is generic
Types ¶
type Parteddata ¶
type Parteddata struct {
// "path":"size":"transport-type":"logical-sector-size":"physical-sector-size":"partition-table-type":"model-name";
Unit_ string // BYT
Path_ string
//Type_ string
Devsize_ string // e.g. 0
DevPath_ string // e.g. /dev/sda
Transporttype_ string
Logicalsectorsize_ string
Physicalsectorsize_ string
Partitiontabletype_ string
Modelname_ string
// "number":"begin":"end":"size":"filesystem-type":"partition-name":"flags-set";
Partnumber_ string // Partition_number
Partbegin_ string
Partend_ string
Partsize_ string
Partfstype_ string
Partname_ string
Flagset_ string
Skip_ bool
}
Parteddata holds parted data
Click to show internal directories.
Click to hide internal directories.